package net.locusworks.crypto;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;
import java.security.spec.EncodedKeySpec;
import java.security.spec.InvalidKeySpecException;
import java.util.Arrays;
import java.util.Base64;
import java.util.Iterator;

import org.apache.commons.io.IOUtils;

import static com.google.common.collect.Iterators.get;
import static com.google.common.collect.Iterators.size;
import static com.google.common.base.Preconditions.checkArgument;

public class AESKeySpec extends EncodedKeySpec {
  
  private static final String AES_MARKER = "aes-seed";

  public AESKeySpec(byte[] encodedKey) {
    super(encodedKey);
  }
  
  public AESKey generateKey() throws InvalidKeySpecException {
    try {
      byte[] data = this.getEncoded();
      InputStream stream = new ByteArrayInputStream(data);
      Iterator<String> parts = Arrays.asList(IOUtils.toString(stream, StandardCharsets.UTF_8).split(" ")).iterator();
      
      checkArgument(size(parts) == 2 && AES_MARKER.equals(get(parts, 0)), "Bad format, should be: aes-seed AAB3...");
      stream = new ByteArrayInputStream(Base64.getDecoder().decode(String.valueOf(get(parts, 1))));
      String marker = IOUtils.toString(stream, StandardCharsets.UTF_8);
      return new AESKey(marker);
    } catch (Exception ex) {
      throw new InvalidKeySpecException(ex);
    }
  }

  @Override
  public String getFormat() {
    return "aes";
  }

}
