package net.locusworks.crypto.utils;

import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

public class DataOutputStreamHelper extends DataOutputStream implements AutoCloseable{

  public DataOutputStreamHelper() {
    this(new ByteArrayOutputStream());
  }
  
  public DataOutputStreamHelper(OutputStream out) {
    super(out);
  }
  
  public byte[] toByteArray() {
    if (super.out == null) {
      return new byte[0];
    }
    if (super.out instanceof ByteArrayOutputStream) {
      return ((ByteArrayOutputStream)super.out).toByteArray();
    }
    return super.out.toString().getBytes(StandardCharsets.UTF_8);
  }
  
  public String base64Encoded() {
    return Base64.getEncoder().encodeToString(this.toByteArray());
  }
  
  @Override
  public String toString() {
   return new String(this.toByteArray(), StandardCharsets.UTF_8);
  }
  
  @Override
  public void close() throws IOException {
   if (super.out != null) {
     try {
       super.out.close();
       super.out = null;
     } catch (Exception ex) {}
   }
  }

}
